package Bundle::MetaSyntactic;

our $VERSION = '1.00';

'whack_eth';

__END__

=head1 NAME

Bundle::MetaSyntactic - All Acme::MetaSyntactic themes

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::MetaSyntactic'>

=head1 DESCRIPTION

C<Acme::MetaSyntactic> is a module designed to fill all your metasyntactic
needs. There was a weekly update with new themes on CPAN between January
15, 2005 and November 6, 2006.

Since version 0.99, the weekly uploads of the module have stopped,
while I take some rest. I'm also looking for a better way to distribute
the core modules and the themes themselves. The current idea is to have
theme packs.

However, some users of C<Acme::MetaSyntactic> desperately needed new
themes to be added, and grew tired of waiting for me. So, in a JFDI way,
they started to upload their own themes on CPAN.

This bundle brings you all the official and not-yet-official
C<Acme::MetaSyntactic> themes, in a single command (see the L<SYNOPSIS>).

=head1 CONTENTS

Acme::MetaSyntactic 0.99 - Themed metasyntactic variables names

Acme::MetaSyntactic::buzzwords - Pointy-haired boss lingo (JQUELIN)

Acme::MetaSyntactic::nethack - The largest time waster in the world of *nix (ELLIOTJS)

Acme::MetaSyntactic::vim - The vim theme (ELLIOTJS)

=head1 AUTHOR

Philippe Bruhat (BooK), <book@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2005-2007 Philippe Bruhat (BooK), All Rights Reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

